# coding: utf-8

"""
    Mux API

    Mux is how developers build online video. This API encompasses both Mux Video and Mux Data functionality to help you build your video-related projects better and faster than ever before.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: devex@mux.com
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from mux_python.configuration import Configuration


class IncidentNotificationRule(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'str',
        'rules': 'list[NotificationRule]',
        'property_id': 'str',
        'id': 'str',
        'action': 'str'
    }

    attribute_map = {
        'status': 'status',
        'rules': 'rules',
        'property_id': 'property_id',
        'id': 'id',
        'action': 'action'
    }

    def __init__(self, status=None, rules=None, property_id=None, id=None, action=None, local_vars_configuration=None):  # noqa: E501
        """IncidentNotificationRule - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._rules = None
        self._property_id = None
        self._id = None
        self._action = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if rules is not None:
            self.rules = rules
        if property_id is not None:
            self.property_id = property_id
        if id is not None:
            self.id = id
        if action is not None:
            self.action = action

    @property
    def status(self):
        """Gets the status of this IncidentNotificationRule.  # noqa: E501


        :return: The status of this IncidentNotificationRule.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this IncidentNotificationRule.


        :param status: The status of this IncidentNotificationRule.  # noqa: E501
        :type status: str
        """

        self._status = status

    @property
    def rules(self):
        """Gets the rules of this IncidentNotificationRule.  # noqa: E501


        :return: The rules of this IncidentNotificationRule.  # noqa: E501
        :rtype: list[NotificationRule]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this IncidentNotificationRule.


        :param rules: The rules of this IncidentNotificationRule.  # noqa: E501
        :type rules: list[NotificationRule]
        """

        self._rules = rules

    @property
    def property_id(self):
        """Gets the property_id of this IncidentNotificationRule.  # noqa: E501


        :return: The property_id of this IncidentNotificationRule.  # noqa: E501
        :rtype: str
        """
        return self._property_id

    @property_id.setter
    def property_id(self, property_id):
        """Sets the property_id of this IncidentNotificationRule.


        :param property_id: The property_id of this IncidentNotificationRule.  # noqa: E501
        :type property_id: str
        """

        self._property_id = property_id

    @property
    def id(self):
        """Gets the id of this IncidentNotificationRule.  # noqa: E501


        :return: The id of this IncidentNotificationRule.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IncidentNotificationRule.


        :param id: The id of this IncidentNotificationRule.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def action(self):
        """Gets the action of this IncidentNotificationRule.  # noqa: E501


        :return: The action of this IncidentNotificationRule.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this IncidentNotificationRule.


        :param action: The action of this IncidentNotificationRule.  # noqa: E501
        :type action: str
        """

        self._action = action

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IncidentNotificationRule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IncidentNotificationRule):
            return True

        return self.to_dict() != other.to_dict()
